#
# spec file for package libepc
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2009 Dominique Leuenberger, Almere, The Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libepc
Summary:        Easy Publish and Consume Library
License:        LGPL-2.1+
Group:          Development/Libraries/GNOME
Version:        0.4.6
Release:        lp152.3.4
Url:            http://live.gnome.org/libepc/
Source:         http://download.gnome.org/sources/libepc/0.4/%{name}-%{version}.tar.xz
BuildRequires:  gdbm-devel
BuildRequires:  intltool
BuildRequires:  libgnutls-devel
BuildRequires:  pkg-config
BuildRequires:  translation-update-upstream
%if 0%{?suse_version} <= 1210
# Only needed for openSUSE <= 12.1; later it is pulled in by rpm-build.
BuildRequires:  xz
%endif
BuildRequires:  pkgconfig(avahi-ui-gtk3)
BuildRequires:  pkgconfig(glib-2.0) >= 2.36
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(uuid)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The Easy Publish and Consume library provides an easy method to:

    * publish data using HTTPS: EpcPublisher
    * announce that information via DNS-SD: EpcDispatcher
    * find that information: EpcConsumer
    * and finally consume it

You can use this library as a key/value store published to the network,
using encryption, authentication and service discovery.


%package 1_0-2
Summary:        Easy Publish and Consume Library
Group:          System/Libraries
Recommends:     %{name}-lang = %{version}
# For lang package to be installable:
Provides:       %{name} = %{version}

%description 1_0-2
The Easy Publish and Consume library provides an easy method to:

    * publish data using HTTPS: EpcPublisher
    * announce that information via DNS-SD: EpcDispatcher
    * find that information: EpcConsumer
    * and finally consume it

You can use this library as a key/value store published to the network,
using encryption, authentication and service discovery.

%package devel
Summary:        Easy Publish and Consume Library
Group:          Development/Libraries/GNOME
Requires:       %{name}-1_0-2 = %{version}
Requires:       gtk2-devel
Requires:       libavahi-devel
Requires:       libavahi-glib-devel
Requires:       libsoup-devel

%description devel
Development headers for libepc.

The Easy Publish and Consume library provides an easy method to:

    * publish data using HTTPS: EpcPublisher
    * announce that information via DNS-SD: EpcDispatcher
    * find that information: EpcConsumer
    * and finally consume it

You can use this library as a key/value store published to the network,
using encryption, authentication and service discovery.


%lang_package
%prep
%setup -q
translation-update-upstream

%build
%configure --disable-static
%__make %{?jobs:-j%jobs}

%install
%makeinstall
find %{buildroot} -type f -name *.la -exec rm {} \;
%find_lang %{name}

%clean
rm -rf %{buildroot}

%post 1_0-2 -p /sbin/ldconfig

%postun 1_0-2 -p /sbin/ldconfig

%files 1_0-2
%defattr(-,root,root)
%{_libdir}/%{name}*.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}-1.0
%{_includedir}/%{name}-ui-1.0
%{_libdir}/*.so
%{_libdir}/pkgconfig/libepc*.pc
%{_datadir}/gtk-doc/html/%{name}-1.0
# Own these repositories to not depend on gtk-doc while building:
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html

%files lang -f %{name}.lang

%changelog
* Fri Jul  7 2017 zaitor@opensuse.org
- Update to version 0.4.6:
  + Examples: Avoid some compiler warnings in the examples.
- Changes from version 0.4.5:
  + Replace (deprecated) g_thread_create() with g_thread_new().
  + Remove use of deprecated g_type_init().
  + Replace (deprecated) GStaticRecMutex with GRecMutex
  + Don't use g_thread_init() or g_thread_supported().
  + Avoid several compiler warnings.
* Tue Jan 31 2012 dimstar@opensuse.org
- Update to version 0.4.4:
  + Correct the libepc-1.0 pkg-config file to mention gnutls,
    bgo#668882.
- Add xz BuildRequires on openSUSE <= 12.1, in order to be able to
  decompress the xz-compressed tarball.
* Tue Nov 22 2011 vuntz@opensuse.org
- Update to version 0.4.3:
  + Correct the libepc-ui-1.0 pkg-config file (bgo#664502).
* Thu Oct 13 2011 vuntz@opensuse.org
- Update to version 0.4.2:
  + Build:
  - examples: Fix linker problems.
  - Avoid use of deprecated G_CONST_RETURN (bgo#660558).
* Fri Sep 30 2011 dimstar@opensuse.org
- Update to version 0.4.1:
  + Really use gtk+ 3 in libepc-ui [bgo#657679]
- Drop libepc-git-fixes.patch: fixed upstream.
- Remove gnome-common BuildRequires and call to gnome-autogen.sh,
  as there is no more patch requiring it.
* Fri Sep 16 2011 vuntz@opensuse.org
- Add libepc-git-fixes.patch: fixes from git to really build
  against GTK+ 3. This is needed for the new totem to build
  correctly with libepc.
- Add gnome-common BuildRequires, and call to gnome-autogen.sh,
  needed for above patch.
* Thu May 26 2011 vuntz@opensuse.org
- Add explicit pkgconfig() BuildRequires instead of relying on
  something else to bring them in: gnutls, uuid.
* Tue May 24 2011 dimstar@opensuse.org
- Update to version 0.4.0:
  + Switch to GTK3:
  - Use avahi-ui-gtk3, instead of avahi-ui [bgo#649404]
  + Fix compilation with GSEAL_ENABLE defined.
- Change -devel style BuildRequires to pkgconfig() ones:
  + Old ones: glib2-devel, libavahi-glib-devel, libsoup-devel.
  + New ones: glib-2.0, libsoup-2.4, avahi-ui-gtk3.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Wed Oct  6 2010 prusnak@opensuse.org
- replace Requires with Recommends for -lang subpackage
* Tue Mar 23 2010 vuntz@opensuse.org
- Update to version 0.3.11:
  + Change a string and add a translator comment. bgo#589339.
  + Fix build failure on kFreeBSD. bgo#592474.
  + Use gtk_widget_get_visible() on GTK+ >= 2.19.7. bgo#612108.
  + Modernise autotools configuration. bgo#613316.
  + Fix some compiler warnings.
  + Updated translations.
* Sat May 23 2009 vuntz@novell.com
- Update to version 0.3.10:
  + epc_shell_create_service_browser(): Fix a warning about no
    return value, possibly avoiding a crash elsewhere.
* Mon May 18 2009 vuntz@novell.com
- Do not use tabs, remove trailing white spaces.
- Split lang package.
* Tue May 12 2009 dominique-obs@leuenberger.net
- Initial package, created during Community Week1
